from __future__ import print_function
from setuptools import setup

setup(
    name="InSAR",
    version="0.0.1",
    author="Mi BoYang",
    author_email="",
    description="InSAR Python",
    # long_description=open("README.rst").read(),
    license="Apache2 License",
    url="",
    packages=['module'],
    install_requires=[
    ],
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        'Programming Language :: Python :: 3.6',
    ],
)
